==> Apache-SWIT-0.15.tar.gz: Apache-SWIT-0.15/lib/Apache/SWIT/Maker/Skeleton/Scaffold/List.pm <==
use strict;
use warnings FATAL => 'all';

package Apache::SWIT::Maker::Skeleton::Scaffold::List;
use base qw(Apache::SWIT::Maker::Skeleton::Page
		Apache::SWIT::Maker::Skeleton::Scaffold);
use Apache::SWIT::Maker::Conversions;

sub list_fields_v {
	my $res = shift()->fields_v;
	shift @$res;
	return $res;
}

sub link_title_v { return conv_table_to_class(shift()->col1_v); }

sub template { return <<'ENDS'; }
use strict;
use warnings FATAL => 'all';

package [% class_v %]::Root::Item;
use base 'HTML::Tested::ClassDBI';
use [% root_class_v %]::DB::[% table_class_v %];
__PACKAGE__->make_tested_link('[% col1_v %]'
		, href_format => '../info/r?edit_link=%s'
		, cdbi_bind => [ [% col1_v %] => 'Primary' ]
		, column_title => '[% link_title_v %]');
[% FOREACH list_fields_v %]__PACKAGE__->make_tested_marked_value('[% field %]'
		, cdbi_bind => '', column_title => '[% title %]');
[% END %]
__PACKAGE__->bind_to_class_dbi('[% root_class_v %]::DB::[% table_class_v %]');

package [% class_v %]::Root;
use base 'HTML::Tested';
__PACKAGE__->make_tested_form('form', default_value => 'u');
__PACKAGE__->make_tested_list('[% list_name_v %]', __PACKAGE__ . '::Item');

package [% class_v %];
use base qw(Apache::SWIT::HTPage);

sub ht_root_class { return __PACKAGE__ . '::Root'; }

sub ht_swit_render {
	my ($class, $r, $root) = @_;
	$root->[% list_name_v %]_containee_do(query_class_dbi => 'retrieve_all');
	return $root;
}

sub ht_swit_update {
	my ($class, $r, $root) = @_;
	return "r";
}

1;
ENDS

1;

==> Apache-SWIT-0.18.tar.gz: Apache-SWIT-0.18/lib/Apache/SWIT/Maker/Skeleton/Scaffold/List.pm <==
use strict;
use warnings FATAL => 'all';

package Apache::SWIT::Maker::Skeleton::Scaffold::List;
use base qw(Apache::SWIT::Maker::Skeleton::Page
		Apache::SWIT::Maker::Skeleton::Scaffold);
use Apache::SWIT::Maker::Conversions;

sub list_fields_v {
	my $res = shift()->fields_v;
	shift @$res;
	return $res;
}

sub link_title_v { return conv_table_to_class(shift()->col1_v); }

sub template { return <<'ENDS'; }
use strict;
use warnings FATAL => 'all';

use HTML::Tested qw(HTV HT);

package [% class_v %]::Root::Item;
use base 'HTML::Tested::ClassDBI';
use [% root_class_v %]::DB::[% table_class_v %];
__PACKAGE__->ht_add_widget(::HTV."::Link", '[% col1_v %]'
		, href_format => '../info/r?edit_link=%s'
		, cdbi_bind => [ [% col1_v %] => 'Primary' ]
		, column_title => '[% link_title_v %]');
[% FOREACH list_fields_v %]__PACKAGE__->ht_add_widget(::HTV."::Marked"
			, '[% field %]', cdbi_bind => ''
			, column_title => '[% title %]');
[% END %]
__PACKAGE__->bind_to_class_dbi('[% root_class_v %]::DB::[% table_class_v %]');

package [% class_v %]::Root;
use base 'HTML::Tested';
__PACKAGE__->ht_add_widget(::HTV."::Form", 'form', default_value => 'u');
__PACKAGE__->ht_add_widget(::HT."::List", '[% list_name_v %]'
	, __PACKAGE__ . '::Item', render_table => 1);

package [% class_v %];
use base qw(Apache::SWIT::HTPage);

sub ht_root_class { return __PACKAGE__ . '::Root'; }

sub ht_swit_render {
	my ($class, $r, $root) = @_;
	$root->[% list_name_v %]_containee_do(query_class_dbi => 'retrieve_all');
	return $root;
}

sub ht_swit_update {
	my ($class, $r, $root) = @_;
	return "r";
}

1;
ENDS

1;
